# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDatabaseDatabaseCatalogsResult',
    'AwaitableGetDatabaseDatabaseCatalogsResult',
    'get_database_database_catalogs',
    'get_database_database_catalogs_output',
]

@pulumi.output_type
class GetDatabaseDatabaseCatalogsResult:
    """
    A collection of values returned by getDatabaseDatabaseCatalogs.
    """
    def __init__(__self__, database_catalogs=None, id=None, instance_name=None, page_size=None, provider_config=None):
        if database_catalogs and not isinstance(database_catalogs, list):
            raise TypeError("Expected argument 'database_catalogs' to be a list")
        pulumi.set(__self__, "database_catalogs", database_catalogs)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_name and not isinstance(instance_name, str):
            raise TypeError("Expected argument 'instance_name' to be a str")
        pulumi.set(__self__, "instance_name", instance_name)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="databaseCatalogs")
    def database_catalogs(self) -> Sequence['outputs.GetDatabaseDatabaseCatalogsDatabaseCatalogResult']:
        return pulumi.get(self, "database_catalogs")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> _builtins.str:
        return pulumi.get(self, "instance_name")

    @_builtins.property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "page_size")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetDatabaseDatabaseCatalogsProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetDatabaseDatabaseCatalogsResult(GetDatabaseDatabaseCatalogsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseDatabaseCatalogsResult(
            database_catalogs=self.database_catalogs,
            id=self.id,
            instance_name=self.instance_name,
            page_size=self.page_size,
            provider_config=self.provider_config)


def get_database_database_catalogs(instance_name: Optional[_builtins.str] = None,
                                   page_size: Optional[_builtins.int] = None,
                                   provider_config: Optional[Union['GetDatabaseDatabaseCatalogsProviderConfigArgs', 'GetDatabaseDatabaseCatalogsProviderConfigArgsDict']] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseDatabaseCatalogsResult:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str instance_name: Name of the instance to get database catalogs for
    :param _builtins.int page_size: Upper bound for items returned
    :param Union['GetDatabaseDatabaseCatalogsProviderConfigArgs', 'GetDatabaseDatabaseCatalogsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['instanceName'] = instance_name
    __args__['pageSize'] = page_size
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getDatabaseDatabaseCatalogs:getDatabaseDatabaseCatalogs', __args__, opts=opts, typ=GetDatabaseDatabaseCatalogsResult).value

    return AwaitableGetDatabaseDatabaseCatalogsResult(
        database_catalogs=pulumi.get(__ret__, 'database_catalogs'),
        id=pulumi.get(__ret__, 'id'),
        instance_name=pulumi.get(__ret__, 'instance_name'),
        page_size=pulumi.get(__ret__, 'page_size'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_database_database_catalogs_output(instance_name: Optional[pulumi.Input[_builtins.str]] = None,
                                          page_size: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                          provider_config: Optional[pulumi.Input[Optional[Union['GetDatabaseDatabaseCatalogsProviderConfigArgs', 'GetDatabaseDatabaseCatalogsProviderConfigArgsDict']]]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseDatabaseCatalogsResult]:
    """
    [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)


    :param _builtins.str instance_name: Name of the instance to get database catalogs for
    :param _builtins.int page_size: Upper bound for items returned
    :param Union['GetDatabaseDatabaseCatalogsProviderConfigArgs', 'GetDatabaseDatabaseCatalogsProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider.
    """
    __args__ = dict()
    __args__['instanceName'] = instance_name
    __args__['pageSize'] = page_size
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getDatabaseDatabaseCatalogs:getDatabaseDatabaseCatalogs', __args__, opts=opts, typ=GetDatabaseDatabaseCatalogsResult)
    return __ret__.apply(lambda __response__: GetDatabaseDatabaseCatalogsResult(
        database_catalogs=pulumi.get(__response__, 'database_catalogs'),
        id=pulumi.get(__response__, 'id'),
        instance_name=pulumi.get(__response__, 'instance_name'),
        page_size=pulumi.get(__response__, 'page_size'),
        provider_config=pulumi.get(__response__, 'provider_config')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['QueryArgs', 'Query']

@pulumi.input_type
class QueryArgs:
    def __init__(__self__, *,
                 display_name: pulumi.Input[_builtins.str],
                 query_text: pulumi.Input[_builtins.str],
                 warehouse_id: pulumi.Input[_builtins.str],
                 apply_auto_limit: Optional[pulumi.Input[_builtins.bool]] = None,
                 catalog: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input['QueryParameterArgs']]]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['QueryProviderConfigArgs']] = None,
                 run_as_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 schema: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Query resource.
        :param pulumi.Input[_builtins.str] display_name: Name of the query.
        :param pulumi.Input[_builtins.str] query_text: Text of SQL query.
        :param pulumi.Input[_builtins.str] warehouse_id: ID of a SQL warehouse which will be used to execute this query.
        :param pulumi.Input[_builtins.bool] apply_auto_limit: Whether to apply a 1000 row limit to the query result.
        :param pulumi.Input[_builtins.str] catalog: Name of the catalog where this query will be executed.
        :param pulumi.Input[_builtins.str] description: General description that conveys additional information about this query such as usage notes.
        :param pulumi.Input[_builtins.str] owner_user_name: Query owner's username.
        :param pulumi.Input[Sequence[pulumi.Input['QueryParameterArgs']]] parameters: Query parameter definition.  Consists of following attributes (one of `*_value` is required):
        :param pulumi.Input[_builtins.str] parent_path: The path to a workspace folder containing the query. The default is the user's home folder.  If changed, the query will be recreated.
        :param pulumi.Input['QueryProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] run_as_mode: Sets the "Run as" role for the object.  Should be one of `OWNER`, `VIEWER`.
        :param pulumi.Input[_builtins.str] schema: Name of the schema where this query will be executed.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags that will be added to the query.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "query_text", query_text)
        pulumi.set(__self__, "warehouse_id", warehouse_id)
        if apply_auto_limit is not None:
            pulumi.set(__self__, "apply_auto_limit", apply_auto_limit)
        if catalog is not None:
            pulumi.set(__self__, "catalog", catalog)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if owner_user_name is not None:
            pulumi.set(__self__, "owner_user_name", owner_user_name)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if parent_path is not None:
            pulumi.set(__self__, "parent_path", parent_path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if run_as_mode is not None:
            pulumi.set(__self__, "run_as_mode", run_as_mode)
        if schema is not None:
            pulumi.set(__self__, "schema", schema)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the query.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="queryText")
    def query_text(self) -> pulumi.Input[_builtins.str]:
        """
        Text of SQL query.
        """
        return pulumi.get(self, "query_text")

    @query_text.setter
    def query_text(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "query_text", value)

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of a SQL warehouse which will be used to execute this query.
        """
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "warehouse_id", value)

    @_builtins.property
    @pulumi.getter(name="applyAutoLimit")
    def apply_auto_limit(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to apply a 1000 row limit to the query result.
        """
        return pulumi.get(self, "apply_auto_limit")

    @apply_auto_limit.setter
    def apply_auto_limit(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "apply_auto_limit", value)

    @_builtins.property
    @pulumi.getter
    def catalog(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the catalog where this query will be executed.
        """
        return pulumi.get(self, "catalog")

    @catalog.setter
    def catalog(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "catalog", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        General description that conveys additional information about this query such as usage notes.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Query owner's username.
        """
        return pulumi.get(self, "owner_user_name")

    @owner_user_name.setter
    def owner_user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner_user_name", value)

    @_builtins.property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QueryParameterArgs']]]]:
        """
        Query parameter definition.  Consists of following attributes (one of `*_value` is required):
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QueryParameterArgs']]]]):
        pulumi.set(self, "parameters", value)

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to a workspace folder containing the query. The default is the user's home folder.  If changed, the query will be recreated.
        """
        return pulumi.get(self, "parent_path")

    @parent_path.setter
    def parent_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_path", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['QueryProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['QueryProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="runAsMode")
    def run_as_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Sets the "Run as" role for the object.  Should be one of `OWNER`, `VIEWER`.
        """
        return pulumi.get(self, "run_as_mode")

    @run_as_mode.setter
    def run_as_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "run_as_mode", value)

    @_builtins.property
    @pulumi.getter
    def schema(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the schema where this query will be executed.
        """
        return pulumi.get(self, "schema")

    @schema.setter
    def schema(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "schema", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags that will be added to the query.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _QueryState:
    def __init__(__self__, *,
                 apply_auto_limit: Optional[pulumi.Input[_builtins.bool]] = None,
                 catalog: Optional[pulumi.Input[_builtins.str]] = None,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 last_modifier_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
                 owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input['QueryParameterArgs']]]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['QueryProviderConfigArgs']] = None,
                 query_text: Optional[pulumi.Input[_builtins.str]] = None,
                 run_as_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 schema: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Query resources.
        :param pulumi.Input[_builtins.bool] apply_auto_limit: Whether to apply a 1000 row limit to the query result.
        :param pulumi.Input[_builtins.str] catalog: Name of the catalog where this query will be executed.
        :param pulumi.Input[_builtins.str] create_time: The timestamp string indicating when the query was created.
        :param pulumi.Input[_builtins.str] description: General description that conveys additional information about this query such as usage notes.
        :param pulumi.Input[_builtins.str] display_name: Name of the query.
        :param pulumi.Input[_builtins.str] last_modifier_user_name: Username of the user who last saved changes to this query.
        :param pulumi.Input[_builtins.str] lifecycle_state: The workspace state of the query. Used for tracking trashed status. (Possible values are `ACTIVE` or `TRASHED`).
        :param pulumi.Input[_builtins.str] owner_user_name: Query owner's username.
        :param pulumi.Input[Sequence[pulumi.Input['QueryParameterArgs']]] parameters: Query parameter definition.  Consists of following attributes (one of `*_value` is required):
        :param pulumi.Input[_builtins.str] parent_path: The path to a workspace folder containing the query. The default is the user's home folder.  If changed, the query will be recreated.
        :param pulumi.Input['QueryProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] query_text: Text of SQL query.
        :param pulumi.Input[_builtins.str] run_as_mode: Sets the "Run as" role for the object.  Should be one of `OWNER`, `VIEWER`.
        :param pulumi.Input[_builtins.str] schema: Name of the schema where this query will be executed.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags that will be added to the query.
        :param pulumi.Input[_builtins.str] update_time: The timestamp string indicating when the query was updated.
        :param pulumi.Input[_builtins.str] warehouse_id: ID of a SQL warehouse which will be used to execute this query.
        """
        if apply_auto_limit is not None:
            pulumi.set(__self__, "apply_auto_limit", apply_auto_limit)
        if catalog is not None:
            pulumi.set(__self__, "catalog", catalog)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if last_modifier_user_name is not None:
            pulumi.set(__self__, "last_modifier_user_name", last_modifier_user_name)
        if lifecycle_state is not None:
            pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if owner_user_name is not None:
            pulumi.set(__self__, "owner_user_name", owner_user_name)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if parent_path is not None:
            pulumi.set(__self__, "parent_path", parent_path)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if query_text is not None:
            pulumi.set(__self__, "query_text", query_text)
        if run_as_mode is not None:
            pulumi.set(__self__, "run_as_mode", run_as_mode)
        if schema is not None:
            pulumi.set(__self__, "schema", schema)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if warehouse_id is not None:
            pulumi.set(__self__, "warehouse_id", warehouse_id)

    @_builtins.property
    @pulumi.getter(name="applyAutoLimit")
    def apply_auto_limit(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to apply a 1000 row limit to the query result.
        """
        return pulumi.get(self, "apply_auto_limit")

    @apply_auto_limit.setter
    def apply_auto_limit(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "apply_auto_limit", value)

    @_builtins.property
    @pulumi.getter
    def catalog(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the catalog where this query will be executed.
        """
        return pulumi.get(self, "catalog")

    @catalog.setter
    def catalog(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "catalog", value)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The timestamp string indicating when the query was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        General description that conveys additional information about this query such as usage notes.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the query.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="lastModifierUserName")
    def last_modifier_user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Username of the user who last saved changes to this query.
        """
        return pulumi.get(self, "last_modifier_user_name")

    @last_modifier_user_name.setter
    def last_modifier_user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_modifier_user_name", value)

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The workspace state of the query. Used for tracking trashed status. (Possible values are `ACTIVE` or `TRASHED`).
        """
        return pulumi.get(self, "lifecycle_state")

    @lifecycle_state.setter
    def lifecycle_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lifecycle_state", value)

    @_builtins.property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Query owner's username.
        """
        return pulumi.get(self, "owner_user_name")

    @owner_user_name.setter
    def owner_user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner_user_name", value)

    @_builtins.property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['QueryParameterArgs']]]]:
        """
        Query parameter definition.  Consists of following attributes (one of `*_value` is required):
        """
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['QueryParameterArgs']]]]):
        pulumi.set(self, "parameters", value)

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The path to a workspace folder containing the query. The default is the user's home folder.  If changed, the query will be recreated.
        """
        return pulumi.get(self, "parent_path")

    @parent_path.setter
    def parent_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_path", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['QueryProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['QueryProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="queryText")
    def query_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Text of SQL query.
        """
        return pulumi.get(self, "query_text")

    @query_text.setter
    def query_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "query_text", value)

    @_builtins.property
    @pulumi.getter(name="runAsMode")
    def run_as_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Sets the "Run as" role for the object.  Should be one of `OWNER`, `VIEWER`.
        """
        return pulumi.get(self, "run_as_mode")

    @run_as_mode.setter
    def run_as_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "run_as_mode", value)

    @_builtins.property
    @pulumi.getter
    def schema(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the schema where this query will be executed.
        """
        return pulumi.get(self, "schema")

    @schema.setter
    def schema(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "schema", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags that will be added to the query.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The timestamp string indicating when the query was updated.
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of a SQL warehouse which will be used to execute this query.
        """
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "warehouse_id", value)


@pulumi.type_token("databricks:index/query:Query")
class Query(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 apply_auto_limit: Optional[pulumi.Input[_builtins.bool]] = None,
                 catalog: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QueryParameterArgs', 'QueryParameterArgsDict']]]]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['QueryProviderConfigArgs', 'QueryProviderConfigArgsDict']]] = None,
                 query_text: Optional[pulumi.Input[_builtins.str]] = None,
                 run_as_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 schema: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource allows you to manage [Databricks SQL Queries](https://docs.databricks.com/en/sql/user/queries/index.html).  It supersedes SqlQuery resource - see migration guide below for more details.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        shared_dir = databricks.Directory("shared_dir", path="/Shared/Queries")
        # This will be replaced with new databricks_query resource
        this = databricks.Query("this",
            warehouse_id=example["id"],
            display_name="My Query Name",
            query_text="SELECT 42 as value",
            parent_path=shared_dir.path)
        ```

        ## Migrating from `SqlQuery` resource

        Under the hood, the new resource uses the same data as the `SqlQuery`, but exposed via different API. This means that we can migrate existing queries without recreating them.  This operation is done in few steps:

        * Record the ID of existing `SqlQuery`, for example, by executing the `terraform state show databricks_sql_query.query` command.
        * Create the code for the new implementation performing following changes:
          * the `name` attribute is now named `display_name`
          * the `parent` (if exists) is renamed to `parent_path` attribute, and should be converted from `folders/object_id` to the actual path.
          * Blocks that specify values in the `parameter` block were renamed (see above).

        For example, if we have the original `SqlQuery` defined as:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        query = databricks.SqlQuery("query",
            data_source_id=example["dataSourceId"],
            query="select 42 as value",
            name="My Query",
            parent=f"folders/{shared_dir['objectId']}",
            parameters=[{
                "name": "p1",
                "title": "Title for p1",
                "text": {
                    "value": "default",
                },
            }])
        ```

        we'll have a new resource defined as:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        query = databricks.Query("query",
            warehouse_id=example["id"],
            query_text="select 42 as value",
            display_name="My Query",
            parent_path=shared_dir["path"],
            parameters=[{
                "name": "p1",
                "title": "Title for p1",
                "text_value": {
                    "value": "default",
                },
            }])
        ```

        ## Access Control

        Permissions can control which groups or individual users can *Manage*, *Edit*, *Run* or *View* individual queries.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        query_usage = databricks.Permissions("query_usage",
            sql_query_id=query["id"],
            access_controls=[{
                "group_name": "users",
                "permission_level": "CAN_RUN",
            }])
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * Alert to manage [Databricks SQL Alerts](https://docs.databricks.com/en/sql/user/alerts/index.html).
        * SqlEndpoint to manage [Databricks SQL Endpoints](https://docs.databricks.com/sql/admin/sql-endpoints.html).
        * Directory to manage directories in [Databricks Workpace](https://docs.databricks.com/workspace/workspace-objects.html).

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] apply_auto_limit: Whether to apply a 1000 row limit to the query result.
        :param pulumi.Input[_builtins.str] catalog: Name of the catalog where this query will be executed.
        :param pulumi.Input[_builtins.str] description: General description that conveys additional information about this query such as usage notes.
        :param pulumi.Input[_builtins.str] display_name: Name of the query.
        :param pulumi.Input[_builtins.str] owner_user_name: Query owner's username.
        :param pulumi.Input[Sequence[pulumi.Input[Union['QueryParameterArgs', 'QueryParameterArgsDict']]]] parameters: Query parameter definition.  Consists of following attributes (one of `*_value` is required):
        :param pulumi.Input[_builtins.str] parent_path: The path to a workspace folder containing the query. The default is the user's home folder.  If changed, the query will be recreated.
        :param pulumi.Input[Union['QueryProviderConfigArgs', 'QueryProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] query_text: Text of SQL query.
        :param pulumi.Input[_builtins.str] run_as_mode: Sets the "Run as" role for the object.  Should be one of `OWNER`, `VIEWER`.
        :param pulumi.Input[_builtins.str] schema: Name of the schema where this query will be executed.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags that will be added to the query.
        :param pulumi.Input[_builtins.str] warehouse_id: ID of a SQL warehouse which will be used to execute this query.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: QueryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to manage [Databricks SQL Queries](https://docs.databricks.com/en/sql/user/queries/index.html).  It supersedes SqlQuery resource - see migration guide below for more details.

        > This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        shared_dir = databricks.Directory("shared_dir", path="/Shared/Queries")
        # This will be replaced with new databricks_query resource
        this = databricks.Query("this",
            warehouse_id=example["id"],
            display_name="My Query Name",
            query_text="SELECT 42 as value",
            parent_path=shared_dir.path)
        ```

        ## Migrating from `SqlQuery` resource

        Under the hood, the new resource uses the same data as the `SqlQuery`, but exposed via different API. This means that we can migrate existing queries without recreating them.  This operation is done in few steps:

        * Record the ID of existing `SqlQuery`, for example, by executing the `terraform state show databricks_sql_query.query` command.
        * Create the code for the new implementation performing following changes:
          * the `name` attribute is now named `display_name`
          * the `parent` (if exists) is renamed to `parent_path` attribute, and should be converted from `folders/object_id` to the actual path.
          * Blocks that specify values in the `parameter` block were renamed (see above).

        For example, if we have the original `SqlQuery` defined as:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        query = databricks.SqlQuery("query",
            data_source_id=example["dataSourceId"],
            query="select 42 as value",
            name="My Query",
            parent=f"folders/{shared_dir['objectId']}",
            parameters=[{
                "name": "p1",
                "title": "Title for p1",
                "text": {
                    "value": "default",
                },
            }])
        ```

        we'll have a new resource defined as:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        query = databricks.Query("query",
            warehouse_id=example["id"],
            query_text="select 42 as value",
            display_name="My Query",
            parent_path=shared_dir["path"],
            parameters=[{
                "name": "p1",
                "title": "Title for p1",
                "text_value": {
                    "value": "default",
                },
            }])
        ```

        ## Access Control

        Permissions can control which groups or individual users can *Manage*, *Edit*, *Run* or *View* individual queries.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        query_usage = databricks.Permissions("query_usage",
            sql_query_id=query["id"],
            access_controls=[{
                "group_name": "users",
                "permission_level": "CAN_RUN",
            }])
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * Alert to manage [Databricks SQL Alerts](https://docs.databricks.com/en/sql/user/alerts/index.html).
        * SqlEndpoint to manage [Databricks SQL Endpoints](https://docs.databricks.com/sql/admin/sql-endpoints.html).
        * Directory to manage directories in [Databricks Workpace](https://docs.databricks.com/workspace/workspace-objects.html).

        :param str resource_name: The name of the resource.
        :param QueryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(QueryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 apply_auto_limit: Optional[pulumi.Input[_builtins.bool]] = None,
                 catalog: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QueryParameterArgs', 'QueryParameterArgsDict']]]]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['QueryProviderConfigArgs', 'QueryProviderConfigArgsDict']]] = None,
                 query_text: Optional[pulumi.Input[_builtins.str]] = None,
                 run_as_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 schema: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = QueryArgs.__new__(QueryArgs)

            __props__.__dict__["apply_auto_limit"] = apply_auto_limit
            __props__.__dict__["catalog"] = catalog
            __props__.__dict__["description"] = description
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["owner_user_name"] = owner_user_name
            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["parent_path"] = parent_path
            __props__.__dict__["provider_config"] = provider_config
            if query_text is None and not opts.urn:
                raise TypeError("Missing required property 'query_text'")
            __props__.__dict__["query_text"] = query_text
            __props__.__dict__["run_as_mode"] = run_as_mode
            __props__.__dict__["schema"] = schema
            __props__.__dict__["tags"] = tags
            if warehouse_id is None and not opts.urn:
                raise TypeError("Missing required property 'warehouse_id'")
            __props__.__dict__["warehouse_id"] = warehouse_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["last_modifier_user_name"] = None
            __props__.__dict__["lifecycle_state"] = None
            __props__.__dict__["update_time"] = None
        super(Query, __self__).__init__(
            'databricks:index/query:Query',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            apply_auto_limit: Optional[pulumi.Input[_builtins.bool]] = None,
            catalog: Optional[pulumi.Input[_builtins.str]] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            last_modifier_user_name: Optional[pulumi.Input[_builtins.str]] = None,
            lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
            owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
            parameters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['QueryParameterArgs', 'QueryParameterArgsDict']]]]] = None,
            parent_path: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['QueryProviderConfigArgs', 'QueryProviderConfigArgsDict']]] = None,
            query_text: Optional[pulumi.Input[_builtins.str]] = None,
            run_as_mode: Optional[pulumi.Input[_builtins.str]] = None,
            schema: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None,
            warehouse_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'Query':
        """
        Get an existing Query resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] apply_auto_limit: Whether to apply a 1000 row limit to the query result.
        :param pulumi.Input[_builtins.str] catalog: Name of the catalog where this query will be executed.
        :param pulumi.Input[_builtins.str] create_time: The timestamp string indicating when the query was created.
        :param pulumi.Input[_builtins.str] description: General description that conveys additional information about this query such as usage notes.
        :param pulumi.Input[_builtins.str] display_name: Name of the query.
        :param pulumi.Input[_builtins.str] last_modifier_user_name: Username of the user who last saved changes to this query.
        :param pulumi.Input[_builtins.str] lifecycle_state: The workspace state of the query. Used for tracking trashed status. (Possible values are `ACTIVE` or `TRASHED`).
        :param pulumi.Input[_builtins.str] owner_user_name: Query owner's username.
        :param pulumi.Input[Sequence[pulumi.Input[Union['QueryParameterArgs', 'QueryParameterArgsDict']]]] parameters: Query parameter definition.  Consists of following attributes (one of `*_value` is required):
        :param pulumi.Input[_builtins.str] parent_path: The path to a workspace folder containing the query. The default is the user's home folder.  If changed, the query will be recreated.
        :param pulumi.Input[Union['QueryProviderConfigArgs', 'QueryProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] query_text: Text of SQL query.
        :param pulumi.Input[_builtins.str] run_as_mode: Sets the "Run as" role for the object.  Should be one of `OWNER`, `VIEWER`.
        :param pulumi.Input[_builtins.str] schema: Name of the schema where this query will be executed.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags that will be added to the query.
        :param pulumi.Input[_builtins.str] update_time: The timestamp string indicating when the query was updated.
        :param pulumi.Input[_builtins.str] warehouse_id: ID of a SQL warehouse which will be used to execute this query.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _QueryState.__new__(_QueryState)

        __props__.__dict__["apply_auto_limit"] = apply_auto_limit
        __props__.__dict__["catalog"] = catalog
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["last_modifier_user_name"] = last_modifier_user_name
        __props__.__dict__["lifecycle_state"] = lifecycle_state
        __props__.__dict__["owner_user_name"] = owner_user_name
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["parent_path"] = parent_path
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["query_text"] = query_text
        __props__.__dict__["run_as_mode"] = run_as_mode
        __props__.__dict__["schema"] = schema
        __props__.__dict__["tags"] = tags
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["warehouse_id"] = warehouse_id
        return Query(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="applyAutoLimit")
    def apply_auto_limit(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether to apply a 1000 row limit to the query result.
        """
        return pulumi.get(self, "apply_auto_limit")

    @_builtins.property
    @pulumi.getter
    def catalog(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the catalog where this query will be executed.
        """
        return pulumi.get(self, "catalog")

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        The timestamp string indicating when the query was created.
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        General description that conveys additional information about this query such as usage notes.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the query.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="lastModifierUserName")
    def last_modifier_user_name(self) -> pulumi.Output[_builtins.str]:
        """
        Username of the user who last saved changes to this query.
        """
        return pulumi.get(self, "last_modifier_user_name")

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> pulumi.Output[_builtins.str]:
        """
        The workspace state of the query. Used for tracking trashed status. (Possible values are `ACTIVE` or `TRASHED`).
        """
        return pulumi.get(self, "lifecycle_state")

    @_builtins.property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Query owner's username.
        """
        return pulumi.get(self, "owner_user_name")

    @_builtins.property
    @pulumi.getter
    def parameters(self) -> pulumi.Output[Optional[Sequence['outputs.QueryParameter']]]:
        """
        Query parameter definition.  Consists of following attributes (one of `*_value` is required):
        """
        return pulumi.get(self, "parameters")

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The path to a workspace folder containing the query. The default is the user's home folder.  If changed, the query will be recreated.
        """
        return pulumi.get(self, "parent_path")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.QueryProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="queryText")
    def query_text(self) -> pulumi.Output[_builtins.str]:
        """
        Text of SQL query.
        """
        return pulumi.get(self, "query_text")

    @_builtins.property
    @pulumi.getter(name="runAsMode")
    def run_as_mode(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Sets the "Run as" role for the object.  Should be one of `OWNER`, `VIEWER`.
        """
        return pulumi.get(self, "run_as_mode")

    @_builtins.property
    @pulumi.getter
    def schema(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the schema where this query will be executed.
        """
        return pulumi.get(self, "schema")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags that will be added to the query.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        The timestamp string indicating when the query was updated.
        """
        return pulumi.get(self, "update_time")

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of a SQL warehouse which will be used to execute this query.
        """
        return pulumi.get(self, "warehouse_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

import types

__config__ = pulumi.Config('databricks')


class _ExportableConfig(types.ModuleType):
    @_builtins.property
    def account_id(self) -> Optional[str]:
        return __config__.get('accountId')

    @_builtins.property
    def actions_id_token_request_token(self) -> Optional[str]:
        return __config__.get('actionsIdTokenRequestToken')

    @_builtins.property
    def actions_id_token_request_url(self) -> Optional[str]:
        return __config__.get('actionsIdTokenRequestUrl')

    @_builtins.property
    def audience(self) -> Optional[str]:
        return __config__.get('audience')

    @_builtins.property
    def auth_type(self) -> Optional[str]:
        return __config__.get('authType')

    @_builtins.property
    def azure_client_id(self) -> Optional[str]:
        return __config__.get('azureClientId')

    @_builtins.property
    def azure_client_secret(self) -> Optional[str]:
        return __config__.get('azureClientSecret')

    @_builtins.property
    def azure_environment(self) -> Optional[str]:
        return __config__.get('azureEnvironment')

    @_builtins.property
    def azure_login_app_id(self) -> Optional[str]:
        return __config__.get('azureLoginAppId')

    @_builtins.property
    def azure_tenant_id(self) -> Optional[str]:
        return __config__.get('azureTenantId')

    @_builtins.property
    def azure_use_msi(self) -> Optional[bool]:
        return __config__.get_bool('azureUseMsi')

    @_builtins.property
    def azure_workspace_resource_id(self) -> Optional[str]:
        return __config__.get('azureWorkspaceResourceId')

    @_builtins.property
    def client_id(self) -> Optional[str]:
        return __config__.get('clientId')

    @_builtins.property
    def client_secret(self) -> Optional[str]:
        return __config__.get('clientSecret')

    @_builtins.property
    def cloud(self) -> Optional[str]:
        return __config__.get('cloud')

    @_builtins.property
    def cluster_id(self) -> Optional[str]:
        return __config__.get('clusterId')

    @_builtins.property
    def config_file(self) -> Optional[str]:
        return __config__.get('configFile')

    @_builtins.property
    def databricks_cli_path(self) -> Optional[str]:
        return __config__.get('databricksCliPath')

    @_builtins.property
    def databricks_id_token_filepath(self) -> Optional[str]:
        return __config__.get('databricksIdTokenFilepath')

    @_builtins.property
    def debug_headers(self) -> Optional[bool]:
        return __config__.get_bool('debugHeaders')

    @_builtins.property
    def debug_truncate_bytes(self) -> Optional[int]:
        return __config__.get_int('debugTruncateBytes')

    @_builtins.property
    def disable_oauth_refresh_token(self) -> Optional[bool]:
        return __config__.get_bool('disableOauthRefreshToken')

    @_builtins.property
    def discovery_url(self) -> Optional[str]:
        return __config__.get('discoveryUrl')

    @_builtins.property
    def experimental_is_unified_host(self) -> Optional[bool]:
        return __config__.get_bool('experimentalIsUnifiedHost')

    @_builtins.property
    def google_credentials(self) -> Optional[str]:
        return __config__.get('googleCredentials')

    @_builtins.property
    def google_service_account(self) -> Optional[str]:
        return __config__.get('googleServiceAccount')

    @_builtins.property
    def host(self) -> Optional[str]:
        return __config__.get('host')

    @_builtins.property
    def http_timeout_seconds(self) -> Optional[int]:
        return __config__.get_int('httpTimeoutSeconds')

    @_builtins.property
    def metadata_service_url(self) -> Optional[str]:
        return __config__.get('metadataServiceUrl')

    @_builtins.property
    def oauth_callback_port(self) -> Optional[int]:
        return __config__.get_int('oauthCallbackPort')

    @_builtins.property
    def oidc_token_env(self) -> Optional[str]:
        return __config__.get('oidcTokenEnv')

    @_builtins.property
    def password(self) -> Optional[str]:
        return __config__.get('password')

    @_builtins.property
    def profile(self) -> Optional[str]:
        return __config__.get('profile')

    @_builtins.property
    def rate_limit(self) -> Optional[int]:
        return __config__.get_int('rateLimit')

    @_builtins.property
    def retry_timeout_seconds(self) -> Optional[int]:
        return __config__.get_int('retryTimeoutSeconds')

    @_builtins.property
    def scopes(self) -> Optional[str]:
        return __config__.get('scopes')

    @_builtins.property
    def serverless_compute_id(self) -> Optional[str]:
        return __config__.get('serverlessComputeId')

    @_builtins.property
    def skip_verify(self) -> Optional[bool]:
        return __config__.get_bool('skipVerify')

    @_builtins.property
    def token(self) -> Optional[str]:
        return __config__.get('token')

    @_builtins.property
    def username(self) -> Optional[str]:
        return __config__.get('username')

    @_builtins.property
    def warehouse_id(self) -> Optional[str]:
        return __config__.get('warehouseId')

    @_builtins.property
    def workspace_id(self) -> Optional[str]:
        return __config__.get('workspaceId')




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceProfileArgs', 'InstanceProfile']

@pulumi.input_type
class InstanceProfileArgs:
    def __init__(__self__, *,
                 instance_profile_arn: pulumi.Input[_builtins.str],
                 iam_role_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 is_meta_instance_profile: Optional[pulumi.Input[_builtins.bool]] = None,
                 provider_config: Optional[pulumi.Input['InstanceProfileProviderConfigArgs']] = None,
                 skip_validation: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a InstanceProfile resource.
        :param pulumi.Input[_builtins.str] instance_profile_arn: `ARN` attribute of `aws_iam_instance_profile` output, the EC2 instance profile association to AWS IAM role. This ARN would be validated upon resource creation.
        :param pulumi.Input[_builtins.str] iam_role_arn: The AWS IAM role ARN of the role associated with the instance profile. It must have the form `arn:aws:iam::<account-id>:role/<name>`. This field is required if your role name and instance profile name do not match and you want to use the instance profile with Databricks SQL Serverless.
        :param pulumi.Input[_builtins.bool] is_meta_instance_profile: Whether the instance profile is a meta instance profile. Used only in [IAM credential passthrough](https://docs.databricks.com/security/credential-passthrough/iam-passthrough.html).
        :param pulumi.Input['InstanceProfileProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.bool] skip_validation: **For advanced usage only.** If validation fails with an error message that does not indicate an IAM related permission issue, (e.g. "Your requested instance type is not supported in your requested availability zone"), you can pass this flag to skip the validation and forcibly add the instance profile.
        """
        pulumi.set(__self__, "instance_profile_arn", instance_profile_arn)
        if iam_role_arn is not None:
            pulumi.set(__self__, "iam_role_arn", iam_role_arn)
        if is_meta_instance_profile is not None:
            pulumi.set(__self__, "is_meta_instance_profile", is_meta_instance_profile)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if skip_validation is not None:
            pulumi.set(__self__, "skip_validation", skip_validation)

    @_builtins.property
    @pulumi.getter(name="instanceProfileArn")
    def instance_profile_arn(self) -> pulumi.Input[_builtins.str]:
        """
        `ARN` attribute of `aws_iam_instance_profile` output, the EC2 instance profile association to AWS IAM role. This ARN would be validated upon resource creation.
        """
        return pulumi.get(self, "instance_profile_arn")

    @instance_profile_arn.setter
    def instance_profile_arn(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "instance_profile_arn", value)

    @_builtins.property
    @pulumi.getter(name="iamRoleArn")
    def iam_role_arn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The AWS IAM role ARN of the role associated with the instance profile. It must have the form `arn:aws:iam::<account-id>:role/<name>`. This field is required if your role name and instance profile name do not match and you want to use the instance profile with Databricks SQL Serverless.
        """
        return pulumi.get(self, "iam_role_arn")

    @iam_role_arn.setter
    def iam_role_arn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "iam_role_arn", value)

    @_builtins.property
    @pulumi.getter(name="isMetaInstanceProfile")
    def is_meta_instance_profile(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the instance profile is a meta instance profile. Used only in [IAM credential passthrough](https://docs.databricks.com/security/credential-passthrough/iam-passthrough.html).
        """
        return pulumi.get(self, "is_meta_instance_profile")

    @is_meta_instance_profile.setter
    def is_meta_instance_profile(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_meta_instance_profile", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['InstanceProfileProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['InstanceProfileProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="skipValidation")
    def skip_validation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        **For advanced usage only.** If validation fails with an error message that does not indicate an IAM related permission issue, (e.g. "Your requested instance type is not supported in your requested availability zone"), you can pass this flag to skip the validation and forcibly add the instance profile.
        """
        return pulumi.get(self, "skip_validation")

    @skip_validation.setter
    def skip_validation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_validation", value)


@pulumi.input_type
class _InstanceProfileState:
    def __init__(__self__, *,
                 iam_role_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 instance_profile_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 is_meta_instance_profile: Optional[pulumi.Input[_builtins.bool]] = None,
                 provider_config: Optional[pulumi.Input['InstanceProfileProviderConfigArgs']] = None,
                 skip_validation: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering InstanceProfile resources.
        :param pulumi.Input[_builtins.str] iam_role_arn: The AWS IAM role ARN of the role associated with the instance profile. It must have the form `arn:aws:iam::<account-id>:role/<name>`. This field is required if your role name and instance profile name do not match and you want to use the instance profile with Databricks SQL Serverless.
        :param pulumi.Input[_builtins.str] instance_profile_arn: `ARN` attribute of `aws_iam_instance_profile` output, the EC2 instance profile association to AWS IAM role. This ARN would be validated upon resource creation.
        :param pulumi.Input[_builtins.bool] is_meta_instance_profile: Whether the instance profile is a meta instance profile. Used only in [IAM credential passthrough](https://docs.databricks.com/security/credential-passthrough/iam-passthrough.html).
        :param pulumi.Input['InstanceProfileProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.bool] skip_validation: **For advanced usage only.** If validation fails with an error message that does not indicate an IAM related permission issue, (e.g. "Your requested instance type is not supported in your requested availability zone"), you can pass this flag to skip the validation and forcibly add the instance profile.
        """
        if iam_role_arn is not None:
            pulumi.set(__self__, "iam_role_arn", iam_role_arn)
        if instance_profile_arn is not None:
            pulumi.set(__self__, "instance_profile_arn", instance_profile_arn)
        if is_meta_instance_profile is not None:
            pulumi.set(__self__, "is_meta_instance_profile", is_meta_instance_profile)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if skip_validation is not None:
            pulumi.set(__self__, "skip_validation", skip_validation)

    @_builtins.property
    @pulumi.getter(name="iamRoleArn")
    def iam_role_arn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The AWS IAM role ARN of the role associated with the instance profile. It must have the form `arn:aws:iam::<account-id>:role/<name>`. This field is required if your role name and instance profile name do not match and you want to use the instance profile with Databricks SQL Serverless.
        """
        return pulumi.get(self, "iam_role_arn")

    @iam_role_arn.setter
    def iam_role_arn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "iam_role_arn", value)

    @_builtins.property
    @pulumi.getter(name="instanceProfileArn")
    def instance_profile_arn(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `ARN` attribute of `aws_iam_instance_profile` output, the EC2 instance profile association to AWS IAM role. This ARN would be validated upon resource creation.
        """
        return pulumi.get(self, "instance_profile_arn")

    @instance_profile_arn.setter
    def instance_profile_arn(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "instance_profile_arn", value)

    @_builtins.property
    @pulumi.getter(name="isMetaInstanceProfile")
    def is_meta_instance_profile(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the instance profile is a meta instance profile. Used only in [IAM credential passthrough](https://docs.databricks.com/security/credential-passthrough/iam-passthrough.html).
        """
        return pulumi.get(self, "is_meta_instance_profile")

    @is_meta_instance_profile.setter
    def is_meta_instance_profile(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_meta_instance_profile", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['InstanceProfileProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['InstanceProfileProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="skipValidation")
    def skip_validation(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        **For advanced usage only.** If validation fails with an error message that does not indicate an IAM related permission issue, (e.g. "Your requested instance type is not supported in your requested availability zone"), you can pass this flag to skip the validation and forcibly add the instance profile.
        """
        return pulumi.get(self, "skip_validation")

    @skip_validation.setter
    def skip_validation(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "skip_validation", value)


@pulumi.type_token("databricks:index/instanceProfile:InstanceProfile")
class InstanceProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 iam_role_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 instance_profile_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 is_meta_instance_profile: Optional[pulumi.Input[_builtins.bool]] = None,
                 provider_config: Optional[pulumi.Input[Union['InstanceProfileProviderConfigArgs', 'InstanceProfileProviderConfigArgsDict']]] = None,
                 skip_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        This resource allows you to manage AWS EC2 instance profiles that users can launch Cluster and access data, like databricks_mount. The following example demonstrates how to create an instance profile and create a cluster with it. When creating a new `InstanceProfile`, Databricks validates that it has sufficient permissions to launch instances with the instance profile. This validation uses AWS dry-run mode for the [AWS EC2 RunInstances API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html).

        > This resource can only be used with a workspace-level provider!

        > Please switch to StorageCredential with Unity Catalog to manage storage credentials, which provides a better and faster way for managing credential security.

        ## Usage with Cluster Policies

        It is advised to keep all common configurations in Cluster Policies to maintain control of the environments launched, so `Cluster` above could be replaced with `ClusterPolicy`:

        ```python
        import pulumi
        import json
        import pulumi_databricks as databricks

        this = databricks.ClusterPolicy("this",
            name="Policy with predefined instance profile",
            definition=json.dumps({
                "aws_attributes.instance_profile_arn": {
                    "type": "fixed",
                    "value": shared["id"],
                },
            }))
        ```

        ## Granting access to all users

        You can make instance profile available to all users by associating it with the special group called `users` through Group data source.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.InstanceProfile("this", instance_profile_arn=shared["id"])
        users = databricks.get_group(display_name="users")
        all = databricks.GroupInstanceProfile("all",
            group_id=users.id,
            instance_profile_id=this.id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] iam_role_arn: The AWS IAM role ARN of the role associated with the instance profile. It must have the form `arn:aws:iam::<account-id>:role/<name>`. This field is required if your role name and instance profile name do not match and you want to use the instance profile with Databricks SQL Serverless.
        :param pulumi.Input[_builtins.str] instance_profile_arn: `ARN` attribute of `aws_iam_instance_profile` output, the EC2 instance profile association to AWS IAM role. This ARN would be validated upon resource creation.
        :param pulumi.Input[_builtins.bool] is_meta_instance_profile: Whether the instance profile is a meta instance profile. Used only in [IAM credential passthrough](https://docs.databricks.com/security/credential-passthrough/iam-passthrough.html).
        :param pulumi.Input[Union['InstanceProfileProviderConfigArgs', 'InstanceProfileProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.bool] skip_validation: **For advanced usage only.** If validation fails with an error message that does not indicate an IAM related permission issue, (e.g. "Your requested instance type is not supported in your requested availability zone"), you can pass this flag to skip the validation and forcibly add the instance profile.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceProfileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to manage AWS EC2 instance profiles that users can launch Cluster and access data, like databricks_mount. The following example demonstrates how to create an instance profile and create a cluster with it. When creating a new `InstanceProfile`, Databricks validates that it has sufficient permissions to launch instances with the instance profile. This validation uses AWS dry-run mode for the [AWS EC2 RunInstances API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html).

        > This resource can only be used with a workspace-level provider!

        > Please switch to StorageCredential with Unity Catalog to manage storage credentials, which provides a better and faster way for managing credential security.

        ## Usage with Cluster Policies

        It is advised to keep all common configurations in Cluster Policies to maintain control of the environments launched, so `Cluster` above could be replaced with `ClusterPolicy`:

        ```python
        import pulumi
        import json
        import pulumi_databricks as databricks

        this = databricks.ClusterPolicy("this",
            name="Policy with predefined instance profile",
            definition=json.dumps({
                "aws_attributes.instance_profile_arn": {
                    "type": "fixed",
                    "value": shared["id"],
                },
            }))
        ```

        ## Granting access to all users

        You can make instance profile available to all users by associating it with the special group called `users` through Group data source.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.InstanceProfile("this", instance_profile_arn=shared["id"])
        users = databricks.get_group(display_name="users")
        all = databricks.GroupInstanceProfile("all",
            group_id=users.id,
            instance_profile_id=this.id)
        ```

        :param str resource_name: The name of the resource.
        :param InstanceProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 iam_role_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 instance_profile_arn: Optional[pulumi.Input[_builtins.str]] = None,
                 is_meta_instance_profile: Optional[pulumi.Input[_builtins.bool]] = None,
                 provider_config: Optional[pulumi.Input[Union['InstanceProfileProviderConfigArgs', 'InstanceProfileProviderConfigArgsDict']]] = None,
                 skip_validation: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceProfileArgs.__new__(InstanceProfileArgs)

            __props__.__dict__["iam_role_arn"] = iam_role_arn
            if instance_profile_arn is None and not opts.urn:
                raise TypeError("Missing required property 'instance_profile_arn'")
            __props__.__dict__["instance_profile_arn"] = instance_profile_arn
            __props__.__dict__["is_meta_instance_profile"] = is_meta_instance_profile
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["skip_validation"] = skip_validation
        super(InstanceProfile, __self__).__init__(
            'databricks:index/instanceProfile:InstanceProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            iam_role_arn: Optional[pulumi.Input[_builtins.str]] = None,
            instance_profile_arn: Optional[pulumi.Input[_builtins.str]] = None,
            is_meta_instance_profile: Optional[pulumi.Input[_builtins.bool]] = None,
            provider_config: Optional[pulumi.Input[Union['InstanceProfileProviderConfigArgs', 'InstanceProfileProviderConfigArgsDict']]] = None,
            skip_validation: Optional[pulumi.Input[_builtins.bool]] = None) -> 'InstanceProfile':
        """
        Get an existing InstanceProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] iam_role_arn: The AWS IAM role ARN of the role associated with the instance profile. It must have the form `arn:aws:iam::<account-id>:role/<name>`. This field is required if your role name and instance profile name do not match and you want to use the instance profile with Databricks SQL Serverless.
        :param pulumi.Input[_builtins.str] instance_profile_arn: `ARN` attribute of `aws_iam_instance_profile` output, the EC2 instance profile association to AWS IAM role. This ARN would be validated upon resource creation.
        :param pulumi.Input[_builtins.bool] is_meta_instance_profile: Whether the instance profile is a meta instance profile. Used only in [IAM credential passthrough](https://docs.databricks.com/security/credential-passthrough/iam-passthrough.html).
        :param pulumi.Input[Union['InstanceProfileProviderConfigArgs', 'InstanceProfileProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.bool] skip_validation: **For advanced usage only.** If validation fails with an error message that does not indicate an IAM related permission issue, (e.g. "Your requested instance type is not supported in your requested availability zone"), you can pass this flag to skip the validation and forcibly add the instance profile.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceProfileState.__new__(_InstanceProfileState)

        __props__.__dict__["iam_role_arn"] = iam_role_arn
        __props__.__dict__["instance_profile_arn"] = instance_profile_arn
        __props__.__dict__["is_meta_instance_profile"] = is_meta_instance_profile
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["skip_validation"] = skip_validation
        return InstanceProfile(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="iamRoleArn")
    def iam_role_arn(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The AWS IAM role ARN of the role associated with the instance profile. It must have the form `arn:aws:iam::<account-id>:role/<name>`. This field is required if your role name and instance profile name do not match and you want to use the instance profile with Databricks SQL Serverless.
        """
        return pulumi.get(self, "iam_role_arn")

    @_builtins.property
    @pulumi.getter(name="instanceProfileArn")
    def instance_profile_arn(self) -> pulumi.Output[_builtins.str]:
        """
        `ARN` attribute of `aws_iam_instance_profile` output, the EC2 instance profile association to AWS IAM role. This ARN would be validated upon resource creation.
        """
        return pulumi.get(self, "instance_profile_arn")

    @_builtins.property
    @pulumi.getter(name="isMetaInstanceProfile")
    def is_meta_instance_profile(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the instance profile is a meta instance profile. Used only in [IAM credential passthrough](https://docs.databricks.com/security/credential-passthrough/iam-passthrough.html).
        """
        return pulumi.get(self, "is_meta_instance_profile")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.InstanceProfileProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="skipValidation")
    def skip_validation(self) -> pulumi.Output[_builtins.bool]:
        """
        **For advanced usage only.** If validation fails with an error message that does not indicate an IAM related permission issue, (e.g. "Your requested instance type is not supported in your requested availability zone"), you can pass this flag to skip the validation and forcibly add the instance profile.
        """
        return pulumi.get(self, "skip_validation")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MetastoreProviderArgs', 'MetastoreProvider']

@pulumi.input_type
class MetastoreProviderArgs:
    def __init__(__self__, *,
                 authentication_type: pulumi.Input[_builtins.str],
                 recipient_profile_str: pulumi.Input[_builtins.str],
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['MetastoreProviderProviderConfigArgs']] = None):
        """
        The set of arguments for constructing a MetastoreProvider resource.
        :param pulumi.Input[_builtins.str] authentication_type: The delta sharing authentication type. Valid values are `TOKEN`.
        :param pulumi.Input[_builtins.str] recipient_profile_str: This is the json file that is created from a recipient url.
        :param pulumi.Input[_builtins.str] comment: Description about the provider.
        :param pulumi.Input[_builtins.str] name: Name of provider. Change forces creation of a new resource.
        :param pulumi.Input['MetastoreProviderProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        pulumi.set(__self__, "authentication_type", authentication_type)
        pulumi.set(__self__, "recipient_profile_str", recipient_profile_str)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="authenticationType")
    def authentication_type(self) -> pulumi.Input[_builtins.str]:
        """
        The delta sharing authentication type. Valid values are `TOKEN`.
        """
        return pulumi.get(self, "authentication_type")

    @authentication_type.setter
    def authentication_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "authentication_type", value)

    @_builtins.property
    @pulumi.getter(name="recipientProfileStr")
    def recipient_profile_str(self) -> pulumi.Input[_builtins.str]:
        """
        This is the json file that is created from a recipient url.
        """
        return pulumi.get(self, "recipient_profile_str")

    @recipient_profile_str.setter
    def recipient_profile_str(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "recipient_profile_str", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description about the provider.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of provider. Change forces creation of a new resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['MetastoreProviderProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['MetastoreProviderProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.input_type
class _MetastoreProviderState:
    def __init__(__self__, *,
                 authentication_type: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['MetastoreProviderProviderConfigArgs']] = None,
                 recipient_profile_str: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering MetastoreProvider resources.
        :param pulumi.Input[_builtins.str] authentication_type: The delta sharing authentication type. Valid values are `TOKEN`.
        :param pulumi.Input[_builtins.str] comment: Description about the provider.
        :param pulumi.Input[_builtins.str] name: Name of provider. Change forces creation of a new resource.
        :param pulumi.Input['MetastoreProviderProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] recipient_profile_str: This is the json file that is created from a recipient url.
        """
        if authentication_type is not None:
            pulumi.set(__self__, "authentication_type", authentication_type)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if recipient_profile_str is not None:
            pulumi.set(__self__, "recipient_profile_str", recipient_profile_str)

    @_builtins.property
    @pulumi.getter(name="authenticationType")
    def authentication_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The delta sharing authentication type. Valid values are `TOKEN`.
        """
        return pulumi.get(self, "authentication_type")

    @authentication_type.setter
    def authentication_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "authentication_type", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description about the provider.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of provider. Change forces creation of a new resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['MetastoreProviderProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['MetastoreProviderProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="recipientProfileStr")
    def recipient_profile_str(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This is the json file that is created from a recipient url.
        """
        return pulumi.get(self, "recipient_profile_str")

    @recipient_profile_str.setter
    def recipient_profile_str(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "recipient_profile_str", value)


@pulumi.type_token("databricks:index/metastoreProvider:MetastoreProvider")
class MetastoreProvider(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_type: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['MetastoreProviderProviderConfigArgs', 'MetastoreProviderProviderConfigArgsDict']]] = None,
                 recipient_profile_str: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        In Delta Sharing, a provider is an entity that shares data with a recipient. Within a metastore, Unity Catalog provides the ability to create a provider which contains a list of shares that have been shared with you.

        > This resource can only be used with a workspace-level provider!

        A `MetastoreProvider` is contained within Metastore and can contain a list of shares that have been shared with you.

        > Databricks to Databricks sharing automatically creates the provider.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_databricks as databricks

        dbprovider = databricks.MetastoreProvider("dbprovider",
            name="terraform-test-provider",
            comment="made by terraform 2",
            authentication_type="TOKEN",
            recipient_profile_str=json.dumps({
                "shareCredentialsVersion": 1,
                "bearerToken": "token",
                "endpoint": "endpoint",
                "expirationTime": "expiration-time",
            }))
        ```

        ## Related Resources

        The following resources are used in the same context:

        * get_tables data to list tables within Unity Catalog.
        * get_schemas data to list schemas within Unity Catalog.
        * get_catalogs data to list catalogs within Unity Catalog.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] authentication_type: The delta sharing authentication type. Valid values are `TOKEN`.
        :param pulumi.Input[_builtins.str] comment: Description about the provider.
        :param pulumi.Input[_builtins.str] name: Name of provider. Change forces creation of a new resource.
        :param pulumi.Input[Union['MetastoreProviderProviderConfigArgs', 'MetastoreProviderProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] recipient_profile_str: This is the json file that is created from a recipient url.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MetastoreProviderArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        In Delta Sharing, a provider is an entity that shares data with a recipient. Within a metastore, Unity Catalog provides the ability to create a provider which contains a list of shares that have been shared with you.

        > This resource can only be used with a workspace-level provider!

        A `MetastoreProvider` is contained within Metastore and can contain a list of shares that have been shared with you.

        > Databricks to Databricks sharing automatically creates the provider.

        ## Example Usage

        ```python
        import pulumi
        import json
        import pulumi_databricks as databricks

        dbprovider = databricks.MetastoreProvider("dbprovider",
            name="terraform-test-provider",
            comment="made by terraform 2",
            authentication_type="TOKEN",
            recipient_profile_str=json.dumps({
                "shareCredentialsVersion": 1,
                "bearerToken": "token",
                "endpoint": "endpoint",
                "expirationTime": "expiration-time",
            }))
        ```

        ## Related Resources

        The following resources are used in the same context:

        * get_tables data to list tables within Unity Catalog.
        * get_schemas data to list schemas within Unity Catalog.
        * get_catalogs data to list catalogs within Unity Catalog.

        :param str resource_name: The name of the resource.
        :param MetastoreProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MetastoreProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authentication_type: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['MetastoreProviderProviderConfigArgs', 'MetastoreProviderProviderConfigArgsDict']]] = None,
                 recipient_profile_str: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MetastoreProviderArgs.__new__(MetastoreProviderArgs)

            if authentication_type is None and not opts.urn:
                raise TypeError("Missing required property 'authentication_type'")
            __props__.__dict__["authentication_type"] = authentication_type
            __props__.__dict__["comment"] = comment
            __props__.__dict__["name"] = name
            __props__.__dict__["provider_config"] = provider_config
            if recipient_profile_str is None and not opts.urn:
                raise TypeError("Missing required property 'recipient_profile_str'")
            __props__.__dict__["recipient_profile_str"] = None if recipient_profile_str is None else pulumi.Output.secret(recipient_profile_str)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["recipientProfileStr"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(MetastoreProvider, __self__).__init__(
            'databricks:index/metastoreProvider:MetastoreProvider',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authentication_type: Optional[pulumi.Input[_builtins.str]] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['MetastoreProviderProviderConfigArgs', 'MetastoreProviderProviderConfigArgsDict']]] = None,
            recipient_profile_str: Optional[pulumi.Input[_builtins.str]] = None) -> 'MetastoreProvider':
        """
        Get an existing MetastoreProvider resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] authentication_type: The delta sharing authentication type. Valid values are `TOKEN`.
        :param pulumi.Input[_builtins.str] comment: Description about the provider.
        :param pulumi.Input[_builtins.str] name: Name of provider. Change forces creation of a new resource.
        :param pulumi.Input[Union['MetastoreProviderProviderConfigArgs', 'MetastoreProviderProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] recipient_profile_str: This is the json file that is created from a recipient url.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MetastoreProviderState.__new__(_MetastoreProviderState)

        __props__.__dict__["authentication_type"] = authentication_type
        __props__.__dict__["comment"] = comment
        __props__.__dict__["name"] = name
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["recipient_profile_str"] = recipient_profile_str
        return MetastoreProvider(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="authenticationType")
    def authentication_type(self) -> pulumi.Output[_builtins.str]:
        """
        The delta sharing authentication type. Valid values are `TOKEN`.
        """
        return pulumi.get(self, "authentication_type")

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description about the provider.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of provider. Change forces creation of a new resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.MetastoreProviderProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="recipientProfileStr")
    def recipient_profile_str(self) -> pulumi.Output[_builtins.str]:
        """
        This is the json file that is created from a recipient url.
        """
        return pulumi.get(self, "recipient_profile_str")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['OboTokenArgs', 'OboToken']

@pulumi.input_type
class OboTokenArgs:
    def __init__(__self__, *,
                 application_id: pulumi.Input[_builtins.str],
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 lifetime_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 provider_config: Optional[pulumi.Input['OboTokenProviderConfigArgs']] = None):
        """
        The set of arguments for constructing a OboToken resource.
        :param pulumi.Input[_builtins.str] application_id: Application ID of ServicePrincipal to create a PAT token for.
        :param pulumi.Input[_builtins.str] comment: Comment that describes the purpose of the token.
        :param pulumi.Input[_builtins.int] lifetime_seconds: The number of seconds before the token expires. Token resource is re-created when it expires. If no lifetime is specified, the token remains valid indefinitely.
        :param pulumi.Input['OboTokenProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        pulumi.set(__self__, "application_id", application_id)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if lifetime_seconds is not None:
            pulumi.set(__self__, "lifetime_seconds", lifetime_seconds)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Input[_builtins.str]:
        """
        Application ID of ServicePrincipal to create a PAT token for.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "application_id", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comment that describes the purpose of the token.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="lifetimeSeconds")
    def lifetime_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds before the token expires. Token resource is re-created when it expires. If no lifetime is specified, the token remains valid indefinitely.
        """
        return pulumi.get(self, "lifetime_seconds")

    @lifetime_seconds.setter
    def lifetime_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "lifetime_seconds", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['OboTokenProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['OboTokenProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)


@pulumi.input_type
class _OboTokenState:
    def __init__(__self__, *,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 lifetime_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 provider_config: Optional[pulumi.Input['OboTokenProviderConfigArgs']] = None,
                 token_value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering OboToken resources.
        :param pulumi.Input[_builtins.str] application_id: Application ID of ServicePrincipal to create a PAT token for.
        :param pulumi.Input[_builtins.str] comment: Comment that describes the purpose of the token.
        :param pulumi.Input[_builtins.int] lifetime_seconds: The number of seconds before the token expires. Token resource is re-created when it expires. If no lifetime is specified, the token remains valid indefinitely.
        :param pulumi.Input['OboTokenProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] token_value: **Sensitive** value of the newly-created token.
        """
        if application_id is not None:
            pulumi.set(__self__, "application_id", application_id)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if lifetime_seconds is not None:
            pulumi.set(__self__, "lifetime_seconds", lifetime_seconds)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if token_value is not None:
            pulumi.set(__self__, "token_value", token_value)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Application ID of ServicePrincipal to create a PAT token for.
        """
        return pulumi.get(self, "application_id")

    @application_id.setter
    def application_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "application_id", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Comment that describes the purpose of the token.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="lifetimeSeconds")
    def lifetime_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds before the token expires. Token resource is re-created when it expires. If no lifetime is specified, the token remains valid indefinitely.
        """
        return pulumi.get(self, "lifetime_seconds")

    @lifetime_seconds.setter
    def lifetime_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "lifetime_seconds", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['OboTokenProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['OboTokenProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="tokenValue")
    def token_value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **Sensitive** value of the newly-created token.
        """
        return pulumi.get(self, "token_value")

    @token_value.setter
    def token_value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token_value", value)


@pulumi.type_token("databricks:index/oboToken:OboToken")
class OboToken(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 lifetime_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 provider_config: Optional[pulumi.Input[Union['OboTokenProviderConfigArgs', 'OboTokenProviderConfigArgsDict']]] = None,
                 __props__=None):
        """
        This resource creates [On-Behalf-Of tokens](https://docs.databricks.com/administration-guide/users-groups/service-principals.html#manage-personal-access-tokens-for-a-service-principal) for a ServicePrincipal in Databricks workspaces on AWS and GCP.  In general it's best to use OAuth authentication using client ID and secret, and use this resource mostly for integrations that doesn't support OAuth.

        > This resource can only be used with a workspace-level provider!

        > To create On-Behalf-Of token for Azure Service Principal, configure Pulumi provider to use Azure service principal's client ID and secret, and use `Token` resource to create a personal access token.

        ## Example Usage

        Creating a token for a narrowly-scoped service principal, that would be the only one (besides admins) allowed to use PAT token in this given workspace, keeping your automated deployment highly secure.

        > A given declaration of `databricks_permissions.token_usage` would OVERWRITE permissions to use PAT tokens from any existing groups with token usage permissions such as the `users` group. To avoid this, be sure to include any desired groups in additional `access_control` blocks in the Pulumi configuration file.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.ServicePrincipal("this", display_name="Automation-only SP")
        token_usage = databricks.Permissions("token_usage",
            authorization="tokens",
            access_controls=[{
                "service_principal_name": this.application_id,
                "permission_level": "CAN_USE",
            }])
        this_obo_token = databricks.OboToken("this",
            application_id=this.application_id,
            comment=this.display_name.apply(lambda display_name: f"PAT on behalf of {display_name}"),
            lifetime_seconds=3600,
            opts = pulumi.ResourceOptions(depends_on=[token_usage]))
        pulumi.export("obo", this_obo_token.token_value)
        ```

        Creating a token for a service principal with admin privileges

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.ServicePrincipal("this", display_name="Pulumi")
        admins = databricks.get_group(display_name="admins")
        this_group_member = databricks.GroupMember("this",
            group_id=admins.id,
            member_id=this.id)
        this_obo_token = databricks.OboToken("this",
            application_id=this.application_id,
            comment=this.display_name.apply(lambda display_name: f"PAT on behalf of {display_name}"),
            lifetime_seconds=3600,
            opts = pulumi.ResourceOptions(depends_on=[this_group_member]))
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * End to end workspace management guide.
        * Group data to retrieve information about Group members, entitlements and instance profiles.
        * GroupMember to attach users and groups as group members.
        * Permissions to manage [access control](https://docs.databricks.com/security/access-control/index.html) in Databricks workspace.
        * ServicePrincipal to manage [Service Principals](https://docs.databricks.com/administration-guide/users-groups/service-principals.html) that could be added to Group within workspace.
        * Grants to manage data access in Unity Catalog.

        ## Import

        !> Importing this resource is not currently supported.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] application_id: Application ID of ServicePrincipal to create a PAT token for.
        :param pulumi.Input[_builtins.str] comment: Comment that describes the purpose of the token.
        :param pulumi.Input[_builtins.int] lifetime_seconds: The number of seconds before the token expires. Token resource is re-created when it expires. If no lifetime is specified, the token remains valid indefinitely.
        :param pulumi.Input[Union['OboTokenProviderConfigArgs', 'OboTokenProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OboTokenArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource creates [On-Behalf-Of tokens](https://docs.databricks.com/administration-guide/users-groups/service-principals.html#manage-personal-access-tokens-for-a-service-principal) for a ServicePrincipal in Databricks workspaces on AWS and GCP.  In general it's best to use OAuth authentication using client ID and secret, and use this resource mostly for integrations that doesn't support OAuth.

        > This resource can only be used with a workspace-level provider!

        > To create On-Behalf-Of token for Azure Service Principal, configure Pulumi provider to use Azure service principal's client ID and secret, and use `Token` resource to create a personal access token.

        ## Example Usage

        Creating a token for a narrowly-scoped service principal, that would be the only one (besides admins) allowed to use PAT token in this given workspace, keeping your automated deployment highly secure.

        > A given declaration of `databricks_permissions.token_usage` would OVERWRITE permissions to use PAT tokens from any existing groups with token usage permissions such as the `users` group. To avoid this, be sure to include any desired groups in additional `access_control` blocks in the Pulumi configuration file.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.ServicePrincipal("this", display_name="Automation-only SP")
        token_usage = databricks.Permissions("token_usage",
            authorization="tokens",
            access_controls=[{
                "service_principal_name": this.application_id,
                "permission_level": "CAN_USE",
            }])
        this_obo_token = databricks.OboToken("this",
            application_id=this.application_id,
            comment=this.display_name.apply(lambda display_name: f"PAT on behalf of {display_name}"),
            lifetime_seconds=3600,
            opts = pulumi.ResourceOptions(depends_on=[token_usage]))
        pulumi.export("obo", this_obo_token.token_value)
        ```

        Creating a token for a service principal with admin privileges

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.ServicePrincipal("this", display_name="Pulumi")
        admins = databricks.get_group(display_name="admins")
        this_group_member = databricks.GroupMember("this",
            group_id=admins.id,
            member_id=this.id)
        this_obo_token = databricks.OboToken("this",
            application_id=this.application_id,
            comment=this.display_name.apply(lambda display_name: f"PAT on behalf of {display_name}"),
            lifetime_seconds=3600,
            opts = pulumi.ResourceOptions(depends_on=[this_group_member]))
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * End to end workspace management guide.
        * Group data to retrieve information about Group members, entitlements and instance profiles.
        * GroupMember to attach users and groups as group members.
        * Permissions to manage [access control](https://docs.databricks.com/security/access-control/index.html) in Databricks workspace.
        * ServicePrincipal to manage [Service Principals](https://docs.databricks.com/administration-guide/users-groups/service-principals.html) that could be added to Group within workspace.
        * Grants to manage data access in Unity Catalog.

        ## Import

        !> Importing this resource is not currently supported.

        :param str resource_name: The name of the resource.
        :param OboTokenArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OboTokenArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 application_id: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 lifetime_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 provider_config: Optional[pulumi.Input[Union['OboTokenProviderConfigArgs', 'OboTokenProviderConfigArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OboTokenArgs.__new__(OboTokenArgs)

            if application_id is None and not opts.urn:
                raise TypeError("Missing required property 'application_id'")
            __props__.__dict__["application_id"] = application_id
            __props__.__dict__["comment"] = comment
            __props__.__dict__["lifetime_seconds"] = lifetime_seconds
            __props__.__dict__["provider_config"] = provider_config
            __props__.__dict__["token_value"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["tokenValue"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(OboToken, __self__).__init__(
            'databricks:index/oboToken:OboToken',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            application_id: Optional[pulumi.Input[_builtins.str]] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            lifetime_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            provider_config: Optional[pulumi.Input[Union['OboTokenProviderConfigArgs', 'OboTokenProviderConfigArgsDict']]] = None,
            token_value: Optional[pulumi.Input[_builtins.str]] = None) -> 'OboToken':
        """
        Get an existing OboToken resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] application_id: Application ID of ServicePrincipal to create a PAT token for.
        :param pulumi.Input[_builtins.str] comment: Comment that describes the purpose of the token.
        :param pulumi.Input[_builtins.int] lifetime_seconds: The number of seconds before the token expires. Token resource is re-created when it expires. If no lifetime is specified, the token remains valid indefinitely.
        :param pulumi.Input[Union['OboTokenProviderConfigArgs', 'OboTokenProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] token_value: **Sensitive** value of the newly-created token.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OboTokenState.__new__(_OboTokenState)

        __props__.__dict__["application_id"] = application_id
        __props__.__dict__["comment"] = comment
        __props__.__dict__["lifetime_seconds"] = lifetime_seconds
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["token_value"] = token_value
        return OboToken(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> pulumi.Output[_builtins.str]:
        """
        Application ID of ServicePrincipal to create a PAT token for.
        """
        return pulumi.get(self, "application_id")

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Comment that describes the purpose of the token.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="lifetimeSeconds")
    def lifetime_seconds(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The number of seconds before the token expires. Token resource is re-created when it expires. If no lifetime is specified, the token remains valid indefinitely.
        """
        return pulumi.get(self, "lifetime_seconds")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.OboTokenProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="tokenValue")
    def token_value(self) -> pulumi.Output[_builtins.str]:
        """
        **Sensitive** value of the newly-created token.
        """
        return pulumi.get(self, "token_value")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VolumeArgs', 'Volume']

@pulumi.input_type
class VolumeArgs:
    def __init__(__self__, *,
                 catalog_name: pulumi.Input[_builtins.str],
                 schema_name: pulumi.Input[_builtins.str],
                 volume_type: pulumi.Input[_builtins.str],
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['VolumeProviderConfigArgs']] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Volume resource.
        :param pulumi.Input[_builtins.str] catalog_name: Name of parent Catalog. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] schema_name: Name of parent Schema relative to parent Catalog. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] volume_type: Volume type. `EXTERNAL` or `MANAGED`. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] comment: Free-form text.
        :param pulumi.Input[_builtins.str] name: Name of the Volume
        :param pulumi.Input[_builtins.str] owner: Name of the volume owner.
        :param pulumi.Input['VolumeProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] storage_location: URL for the volume (should be inside of an existing External Location). Only used for `EXTERNAL` Volumes.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource.
        """
        pulumi.set(__self__, "catalog_name", catalog_name)
        pulumi.set(__self__, "schema_name", schema_name)
        pulumi.set(__self__, "volume_type", volume_type)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if storage_location is not None:
            pulumi.set(__self__, "storage_location", storage_location)

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of parent Catalog. Change forces creation of a new resource.
        """
        return pulumi.get(self, "catalog_name")

    @catalog_name.setter
    def catalog_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "catalog_name", value)

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of parent Schema relative to parent Catalog. Change forces creation of a new resource.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "schema_name", value)

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> pulumi.Input[_builtins.str]:
        """
        Volume type. `EXTERNAL` or `MANAGED`. Change forces creation of a new resource.
        """
        return pulumi.get(self, "volume_type")

    @volume_type.setter
    def volume_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "volume_type", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Free-form text.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Volume
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the volume owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['VolumeProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['VolumeProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="storageLocation")
    def storage_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL for the volume (should be inside of an existing External Location). Only used for `EXTERNAL` Volumes.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource.
        """
        return pulumi.get(self, "storage_location")

    @storage_location.setter
    def storage_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_location", value)


@pulumi.input_type
class _VolumeState:
    def __init__(__self__, *,
                 catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input['VolumeProviderConfigArgs']] = None,
                 schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_path: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Volume resources.
        :param pulumi.Input[_builtins.str] catalog_name: Name of parent Catalog. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] comment: Free-form text.
        :param pulumi.Input[_builtins.str] name: Name of the Volume
        :param pulumi.Input[_builtins.str] owner: Name of the volume owner.
        :param pulumi.Input['VolumeProviderConfigArgs'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] schema_name: Name of parent Schema relative to parent Catalog. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] storage_location: URL for the volume (should be inside of an existing External Location). Only used for `EXTERNAL` Volumes.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] volume_path: base file path for this Unity Catalog Volume in form of `/Volumes/<catalog>/<schema>/<name>`.
        :param pulumi.Input[_builtins.str] volume_type: Volume type. `EXTERNAL` or `MANAGED`. Change forces creation of a new resource.
        """
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if provider_config is not None:
            pulumi.set(__self__, "provider_config", provider_config)
        if schema_name is not None:
            pulumi.set(__self__, "schema_name", schema_name)
        if storage_location is not None:
            pulumi.set(__self__, "storage_location", storage_location)
        if volume_path is not None:
            pulumi.set(__self__, "volume_path", volume_path)
        if volume_type is not None:
            pulumi.set(__self__, "volume_type", volume_type)

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of parent Catalog. Change forces creation of a new resource.
        """
        return pulumi.get(self, "catalog_name")

    @catalog_name.setter
    def catalog_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "catalog_name", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Free-form text.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Volume
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the volume owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner", value)

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional[pulumi.Input['VolumeProviderConfigArgs']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @provider_config.setter
    def provider_config(self, value: Optional[pulumi.Input['VolumeProviderConfigArgs']]):
        pulumi.set(self, "provider_config", value)

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of parent Schema relative to parent Catalog. Change forces creation of a new resource.
        """
        return pulumi.get(self, "schema_name")

    @schema_name.setter
    def schema_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "schema_name", value)

    @_builtins.property
    @pulumi.getter(name="storageLocation")
    def storage_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL for the volume (should be inside of an existing External Location). Only used for `EXTERNAL` Volumes.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource.
        """
        return pulumi.get(self, "storage_location")

    @storage_location.setter
    def storage_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "storage_location", value)

    @_builtins.property
    @pulumi.getter(name="volumePath")
    def volume_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        base file path for this Unity Catalog Volume in form of `/Volumes/<catalog>/<schema>/<name>`.
        """
        return pulumi.get(self, "volume_path")

    @volume_path.setter
    def volume_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "volume_path", value)

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Volume type. `EXTERNAL` or `MANAGED`. Change forces creation of a new resource.
        """
        return pulumi.get(self, "volume_type")

    @volume_type.setter
    def volume_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "volume_type", value)


@pulumi.type_token("databricks:index/volume:Volume")
class Volume(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['VolumeProviderConfigArgs', 'VolumeProviderConfigArgsDict']]] = None,
                 schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Volumes are Unity Catalog objects representing a logical volume of storage in a cloud object storage location. Volumes provide capabilities for accessing, storing, governing, and organizing files. While tables provide governance over tabular datasets, volumes add governance over non-tabular datasets. You can use volumes to store and access files in any format, including structured, semi-structured, and unstructured data.

        > This resource can only be used with a workspace-level provider!

        A volume resides in the third layer of Unity Catalog's three-level namespace. Volumes are siblings to tables, views, and other objects organized under a schema in Unity Catalog.

        A volume can be **managed** or **external**.

        A **managed volume** is a Unity Catalog-governed storage volume created within the default storage location of the containing schema. Managed volumes allow the creation of governed storage for working with files without the overhead of external locations and storage credentials. You do not need to specify a location when creating a managed volume, and all file access for data in managed volumes is through paths managed by Unity Catalog.

        An **external volume** is a Unity Catalog-governed storage volume registered against a directory within an external location.

        A volume can be referenced using its identifier: ```<catalogName>.<schemaName>.<volumeName>```, where:

        * ```<catalogName>```: The name of the catalog containing the Volume.
        * ```<schemaName>```: The name of the schema containing the Volume.
        * ```<volumeName>```: The name of the Volume. It identifies the volume object.

        The path to access files in volumes uses the following format:

        ```/Volumes/<catalog>/<schema>/<volume>/<path>/<file_name>```

        Databricks also supports an optional ```dbfs:/``` scheme, so the following path also works:

        ```dbfs:/Volumes/<catalog>/<schema>/<volume>/<path>/<file_name>```

        This resource manages Volumes in Unity Catalog.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        sandbox = databricks.Catalog("sandbox",
            name="sandbox",
            comment="this catalog is managed by terraform",
            properties={
                "purpose": "testing",
            })
        things = databricks.Schema("things",
            catalog_name=sandbox.name,
            name="things",
            comment="this schema is managed by terraform",
            properties={
                "kind": "various",
            })
        external = databricks.StorageCredential("external",
            name="creds",
            aws_iam_role={
                "role_arn": external_data_access["arn"],
            })
        some = databricks.ExternalLocation("some",
            name="external_location",
            url=f"s3://{external_aws_s3_bucket['id']}/some",
            credential_name=external.name)
        this = databricks.Volume("this",
            name="quickstart_volume",
            catalog_name=sandbox.name,
            schema_name=things.name,
            volume_type="EXTERNAL",
            storage_location=some.url,
            comment="this volume is managed by terraform")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] catalog_name: Name of parent Catalog. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] comment: Free-form text.
        :param pulumi.Input[_builtins.str] name: Name of the Volume
        :param pulumi.Input[_builtins.str] owner: Name of the volume owner.
        :param pulumi.Input[Union['VolumeProviderConfigArgs', 'VolumeProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] schema_name: Name of parent Schema relative to parent Catalog. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] storage_location: URL for the volume (should be inside of an existing External Location). Only used for `EXTERNAL` Volumes.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] volume_type: Volume type. `EXTERNAL` or `MANAGED`. Change forces creation of a new resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VolumeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Volumes are Unity Catalog objects representing a logical volume of storage in a cloud object storage location. Volumes provide capabilities for accessing, storing, governing, and organizing files. While tables provide governance over tabular datasets, volumes add governance over non-tabular datasets. You can use volumes to store and access files in any format, including structured, semi-structured, and unstructured data.

        > This resource can only be used with a workspace-level provider!

        A volume resides in the third layer of Unity Catalog's three-level namespace. Volumes are siblings to tables, views, and other objects organized under a schema in Unity Catalog.

        A volume can be **managed** or **external**.

        A **managed volume** is a Unity Catalog-governed storage volume created within the default storage location of the containing schema. Managed volumes allow the creation of governed storage for working with files without the overhead of external locations and storage credentials. You do not need to specify a location when creating a managed volume, and all file access for data in managed volumes is through paths managed by Unity Catalog.

        An **external volume** is a Unity Catalog-governed storage volume registered against a directory within an external location.

        A volume can be referenced using its identifier: ```<catalogName>.<schemaName>.<volumeName>```, where:

        * ```<catalogName>```: The name of the catalog containing the Volume.
        * ```<schemaName>```: The name of the schema containing the Volume.
        * ```<volumeName>```: The name of the Volume. It identifies the volume object.

        The path to access files in volumes uses the following format:

        ```/Volumes/<catalog>/<schema>/<volume>/<path>/<file_name>```

        Databricks also supports an optional ```dbfs:/``` scheme, so the following path also works:

        ```dbfs:/Volumes/<catalog>/<schema>/<volume>/<path>/<file_name>```

        This resource manages Volumes in Unity Catalog.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        sandbox = databricks.Catalog("sandbox",
            name="sandbox",
            comment="this catalog is managed by terraform",
            properties={
                "purpose": "testing",
            })
        things = databricks.Schema("things",
            catalog_name=sandbox.name,
            name="things",
            comment="this schema is managed by terraform",
            properties={
                "kind": "various",
            })
        external = databricks.StorageCredential("external",
            name="creds",
            aws_iam_role={
                "role_arn": external_data_access["arn"],
            })
        some = databricks.ExternalLocation("some",
            name="external_location",
            url=f"s3://{external_aws_s3_bucket['id']}/some",
            credential_name=external.name)
        this = databricks.Volume("this",
            name="quickstart_volume",
            catalog_name=sandbox.name,
            schema_name=things.name,
            volume_type="EXTERNAL",
            storage_location=some.url,
            comment="this volume is managed by terraform")
        ```

        :param str resource_name: The name of the resource.
        :param VolumeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VolumeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 owner: Optional[pulumi.Input[_builtins.str]] = None,
                 provider_config: Optional[pulumi.Input[Union['VolumeProviderConfigArgs', 'VolumeProviderConfigArgsDict']]] = None,
                 schema_name: Optional[pulumi.Input[_builtins.str]] = None,
                 storage_location: Optional[pulumi.Input[_builtins.str]] = None,
                 volume_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VolumeArgs.__new__(VolumeArgs)

            if catalog_name is None and not opts.urn:
                raise TypeError("Missing required property 'catalog_name'")
            __props__.__dict__["catalog_name"] = catalog_name
            __props__.__dict__["comment"] = comment
            __props__.__dict__["name"] = name
            __props__.__dict__["owner"] = owner
            __props__.__dict__["provider_config"] = provider_config
            if schema_name is None and not opts.urn:
                raise TypeError("Missing required property 'schema_name'")
            __props__.__dict__["schema_name"] = schema_name
            __props__.__dict__["storage_location"] = storage_location
            if volume_type is None and not opts.urn:
                raise TypeError("Missing required property 'volume_type'")
            __props__.__dict__["volume_type"] = volume_type
            __props__.__dict__["volume_path"] = None
        super(Volume, __self__).__init__(
            'databricks:index/volume:Volume',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            owner: Optional[pulumi.Input[_builtins.str]] = None,
            provider_config: Optional[pulumi.Input[Union['VolumeProviderConfigArgs', 'VolumeProviderConfigArgsDict']]] = None,
            schema_name: Optional[pulumi.Input[_builtins.str]] = None,
            storage_location: Optional[pulumi.Input[_builtins.str]] = None,
            volume_path: Optional[pulumi.Input[_builtins.str]] = None,
            volume_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Volume':
        """
        Get an existing Volume resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] catalog_name: Name of parent Catalog. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] comment: Free-form text.
        :param pulumi.Input[_builtins.str] name: Name of the Volume
        :param pulumi.Input[_builtins.str] owner: Name of the volume owner.
        :param pulumi.Input[Union['VolumeProviderConfigArgs', 'VolumeProviderConfigArgsDict']] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
        :param pulumi.Input[_builtins.str] schema_name: Name of parent Schema relative to parent Catalog. Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] storage_location: URL for the volume (should be inside of an existing External Location). Only used for `EXTERNAL` Volumes.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource.
        :param pulumi.Input[_builtins.str] volume_path: base file path for this Unity Catalog Volume in form of `/Volumes/<catalog>/<schema>/<name>`.
        :param pulumi.Input[_builtins.str] volume_type: Volume type. `EXTERNAL` or `MANAGED`. Change forces creation of a new resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VolumeState.__new__(_VolumeState)

        __props__.__dict__["catalog_name"] = catalog_name
        __props__.__dict__["comment"] = comment
        __props__.__dict__["name"] = name
        __props__.__dict__["owner"] = owner
        __props__.__dict__["provider_config"] = provider_config
        __props__.__dict__["schema_name"] = schema_name
        __props__.__dict__["storage_location"] = storage_location
        __props__.__dict__["volume_path"] = volume_path
        __props__.__dict__["volume_type"] = volume_type
        return Volume(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of parent Catalog. Change forces creation of a new resource.
        """
        return pulumi.get(self, "catalog_name")

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Free-form text.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Volume
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the volume owner.
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> pulumi.Output[Optional['outputs.VolumeProviderConfig']]:
        """
        Configure the provider for management through account provider. This block consists of the following fields:
        """
        return pulumi.get(self, "provider_config")

    @_builtins.property
    @pulumi.getter(name="schemaName")
    def schema_name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of parent Schema relative to parent Catalog. Change forces creation of a new resource.
        """
        return pulumi.get(self, "schema_name")

    @_builtins.property
    @pulumi.getter(name="storageLocation")
    def storage_location(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        URL for the volume (should be inside of an existing External Location). Only used for `EXTERNAL` Volumes.  If the URL contains special characters, such as space, `&`, etc., they should be percent-encoded (space > `%20`, etc.). Change forces creation of a new resource.
        """
        return pulumi.get(self, "storage_location")

    @_builtins.property
    @pulumi.getter(name="volumePath")
    def volume_path(self) -> pulumi.Output[_builtins.str]:
        """
        base file path for this Unity Catalog Volume in form of `/Volumes/<catalog>/<schema>/<name>`.
        """
        return pulumi.get(self, "volume_path")

    @_builtins.property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> pulumi.Output[_builtins.str]:
        """
        Volume type. `EXTERNAL` or `MANAGED`. Change forces creation of a new resource.
        """
        return pulumi.get(self, "volume_type")

